@@ -6,8 +6,6 @@ import click
 from click_help_colors import HelpColorsGroup
 
 from xp.cli.commands import homekit
-from xp.cli.commands.api import api
-from xp.cli.commands.cache_commands import cache
 from xp.cli.commands.conbus.conbus import conbus
 from xp.cli.commands.file_commands import file
 from xp.cli.commands.module_commands import module
@@ -28,7 +26,11 @@ from xp.utils.dependencies import ServiceContainer
 @click.version_option()
 @click.pass_context
 def cli(ctx: click.Context) -> None:
-    """XP CLI tool for remote console bus operations"""
+    """XP CLI tool for remote console bus operations.
+
+    Args:
+        ctx: Click context object for passing state between commands.
+    """
     # Configure logging with thread information
     log_format = "%(asctime)s - [%(threadName)s-%(thread)d] - %(levelname)s - %(name)s - %(message)s"
     date_format = "%H:%M:%S"
@@ -46,17 +48,21 @@ def cli(ctx: click.Context) -> None:
         handler = logging.StreamHandler()
         handler.setFormatter(formatter)
         root_logger.addHandler(handler)
-    # Suppress pyhap.hap_protocol logs
-    logging.getLogger("pyhap.hap_protocol").setLevel(logging.WARNING)
-    logging.getLogger("pyhap.hap_handler").setLevel(logging.WARNING)
-    # logging.getLogger('pyhap.accessory_driver').setLevel(logging.WARNING)
 
-    # Ensure xp module logs at DEBUG level
+    # Suppress pyhap.hap_protocol logs
+
+    # bubus
+    logging.getLogger("bubus").setLevel(logging.WARNING)
+
+    # xp
     logging.getLogger("xp").setLevel(logging.DEBUG)
-    logging.getLogger("xp.services.homekit.homekit_service").setLevel(logging.INFO)
-    # logging.getLogger("xp.services.protocol.telegram_protocol").setLevel(logging.INFO)
-    logging.getLogger("pyhap").setLevel(logging.DEBUG)
-    logging.getLogger("bubus").setLevel(logging.DEBUG)
+    logging.getLogger("xp.services.homekit").setLevel(logging.WARNING)
+
+    # pyhap
+    logging.getLogger("pyhap").setLevel(logging.WARNING)
+    logging.getLogger("pyhap.hap_handler").setLevel(logging.WARNING)
+    logging.getLogger("pyhap.hap_protocol").setLevel(logging.WARNING)
+    # logging.getLogger('pyhap.accessory_driver').setLevel(logging.WARNING)
 
     # Initialize the service container and store it in the context
     ctx.ensure_object(dict)
@@ -66,14 +72,12 @@ def cli(ctx: click.Context) -> None:
 
 
 # Register all command groups
-cli.add_command(cache)
 cli.add_command(conbus)
 cli.add_command(homekit)
 cli.add_command(telegram)
 cli.add_command(module)
 cli.add_command(file)
 cli.add_command(server)
-cli.add_command(api)
 cli.add_command(reverse_proxy)
 
 # Add the tree command
