@@ -1,13 +1,29 @@
-# save as click_tree.py
+"""Utilities for displaying Click command trees."""
+
 from typing import Any
 
 import click
 
 
 def add_tree_command(cli_group: click.Group, command_name: str = "help") -> Any:
-    """Add a tree command to any Click group"""
+    """Add a tree command to any Click group.
+
+    Args:
+        cli_group: The Click group to add the tree command to.
+        command_name: Name of the tree command (default: "help").
+
+    Returns:
+        The tree command function.
+    """
 
     def print_command_tree(group: click.Group, ctx: click.Context, suffix: str) -> None:
+        """Print command tree recursively.
+
+        Args:
+            group: The Click group to print.
+            ctx: The Click context.
+            suffix: Prefix string for tree display.
+        """
         for name in sorted(group.list_commands(ctx)):
             cmd = group.get_command(ctx, name)
 
@@ -23,7 +39,11 @@ def add_tree_command(cli_group: click.Group, command_name: str = "help") -> Any:
     @cli_group.command(command_name)
     @click.pass_context
     def tree_command(ctx: click.Context) -> None:
-        """Show complete command tree"""
+        """Show complete command tree.
+
+        Args:
+            ctx: The Click context.
+        """
         root = ctx.find_root().command
         root_ctx = ctx.find_root()
         root_name = root_ctx.info_name or "cli"
