@@ -1,3 +1,5 @@
+"""Click parameter type for DataPointType enum validation."""
+
 from typing import Any, Optional
 
 import click
@@ -7,14 +9,32 @@ from xp.models.telegram.datapoint_type import DataPointType
 
 # noinspection DuplicatedCode
 class DatapointTypeChoice(click.ParamType):
+    """Click parameter type for validating DataPointType enum values.
+
+    Attributes:
+        name: The parameter type name.
+        choices: List of valid choice strings.
+    """
+
     name = "telegram_type"
 
     def __init__(self) -> None:
+        """Initialize the DatapointTypeChoice parameter type."""
         self.choices = [key.lower() for key in DataPointType.__members__.keys()]
 
     def convert(
         self, value: Any, param: Optional[click.Parameter], ctx: Optional[click.Context]
     ) -> Any:
+        """Convert and validate input to DataPointType enum.
+
+        Args:
+            value: The input value to convert.
+            param: The Click parameter.
+            ctx: The Click context.
+
+        Returns:
+            DataPointType enum member if valid, None if input is None.
+        """
         if value is None:
             return value
 
