@@ -1,5 +1,9 @@
+"""HomeKit Dimming Light Accessory.
+
+This module provides a dimming light accessory for HomeKit integration.
+"""
+
 import logging
-from typing import Optional
 
 from bubus import EventBus
 from pyhap.accessory import Accessory
@@ -9,17 +13,28 @@ from pyhap.const import CATEGORY_LIGHTBULB
 from xp.models.homekit.homekit_config import HomekitAccessoryConfig
 from xp.models.homekit.homekit_conson_config import ConsonModuleConfig
 from xp.models.protocol.conbus_protocol import (
-    DatapointReceivedEvent,
     DimmingLightGetBrightnessEvent,
     DimmingLightGetOnEvent,
     DimmingLightSetBrightnessEvent,
     DimmingLightSetOnEvent,
 )
-from xp.models.telegram.datapoint_type import DataPointType
 
 
 class DimmingLight(Accessory):
-    """Fake lightbulb, logs what the client sets."""
+    """HomeKit dimming light accessory.
+
+    Attributes:
+        category: HomeKit category (CATEGORY_LIGHTBULB).
+        event_bus: Event bus for inter-service communication.
+        logger: Logger instance.
+        identifier: Unique identifier for the accessory.
+        accessory: Accessory configuration.
+        module: Module configuration.
+        is_on: Current on/off state.
+        brightness: Current brightness level (0-100).
+        char_on: On characteristic.
+        char_brightness: Brightness characteristic.
+    """
 
     category = CATEGORY_LIGHTBULB
     event_bus: EventBus
@@ -31,9 +46,24 @@ class DimmingLight(Accessory):
         accessory: HomekitAccessoryConfig,
         event_bus: EventBus,
     ):
+        """Initialize the dimming light accessory.
+
+        Args:
+            driver: HAP accessory driver.
+            module: Module configuration.
+            accessory: Accessory configuration.
+            event_bus: Event bus for inter-service communication.
+        """
         super().__init__(driver, accessory.description)
 
         self.logger = logging.getLogger(__name__)
+
+        identifier = f"{module.serial_number}.{accessory.output_number:02d}"
+        version = accessory.id
+        manufacturer = "Conson"
+        model = "XP33LED_Lightdimmer"
+
+        self.identifier = identifier
         self.accessory = accessory
         self.module = module
         self.event_bus = event_bus
@@ -41,19 +71,12 @@ class DimmingLight(Accessory):
         self.is_on: bool = True
         self.brightness: int = 0
 
-        self.event_bus.on(DatapointReceivedEvent, self.on_is_on_received)
-        self.event_bus.on(DatapointReceivedEvent, self.on_brightness_received)
-
         self.logger.info(
             "Creating DimmingLight { serial_number : %s, output_number: %s }",
             module.serial_number,
             accessory.output_number,
         )
 
-        serial = f"{module.serial_number}.{accessory.output_number:02d}"
-        version = accessory.id
-        manufacturer = "Conson"
-        model = "XP33LED_Lightdimmer"
         serv_light = self.add_preload_service(
             "Lightbulb",
             [
@@ -62,7 +85,7 @@ class DimmingLight(Accessory):
                 "Brightness"
             ],
         )
-        self.set_info_service(version, manufacturer, model, serial)
+        self.set_info_service(version, manufacturer, model, identifier)
 
         self.char_on = serv_light.configure_char(
             "On", getter_callback=self.get_on, setter_callback=self.set_on, value=False
@@ -73,71 +96,39 @@ class DimmingLight(Accessory):
             getter_callback=self.get_brightness,
             setter_callback=self.set_brightness,
         )
-
-    def on_is_on_received(self, event: DatapointReceivedEvent) -> Optional[bool]:
-
-        if (
-            event.serial_number != self.module.serial_number
-            or event.datapoint_type != DataPointType.MODULE_OUTPUT_STATE
-        ):
-            return None
-
-        is_on = event.data_value[::-1][self.accessory.output_number] == "1"
+        self.logger.debug(f"char_on properties: {self.char_on.properties}")
         self.logger.debug(
-            f"on_is_on_received "
-            f"serial_number: {event.serial_number}, "
-            f"output_number: {self.accessory.output_number}, "
-            f"data_vale: {event.data_value}"
-            f"is_on: {is_on}"
+            f"char_brightness properties: {self.char_brightness.properties}"
         )
-        self.is_on = is_on
-        return is_on
-
-    def on_brightness_received(self, event: DatapointReceivedEvent) -> Optional[int]:
-
-        if (
-            event.serial_number != self.module.serial_number
-            or event.datapoint_type != DataPointType.MODULE_LIGHT_LEVEL
-        ):
-            return None
-
-        # Parse response format like "00:050,01:025,02:100"
-        data_value = event.data_value
-        self.logger.debug(f"Parsing brightness from response: {data_value}")
-        brightness = 0
-        for output_data in data_value.split(","):
-            if ":" in output_data:
-                output_str, level_str = output_data.split(":")
-                if int(output_str) == self.accessory.output_number:
-                    brightness = int(level_str)
-                    break
-
-        self.logger.debug(
-            f"on_brightness_received "
-            f"serial_number: {event.serial_number}, "
-            f"output_number: {self.accessory.output_number}, "
-            f"data_vale: {event.data_value}"
-            f"brightness: {brightness}"
-        )
-        self.brightness = brightness
-        return brightness
 
     def set_on(self, value: bool) -> None:
+        """Set the on/off state of the dimming light.
+
+        Args:
+            value: True to turn on, False to turn off.
+        """
         # Emit set event
         self.logger.debug(f"set_on {value}")
 
-        self.is_on = value
-        self.event_bus.dispatch(
-            DimmingLightSetOnEvent(
-                serial_number=self.accessory.serial_number,
-                output_number=self.accessory.output_number,
-                module=self.module,
-                accessory=self.accessory,
-                value=value,
+        if value != self.is_on:
+            self.is_on = value
+            self.event_bus.dispatch(
+                DimmingLightSetOnEvent(
+                    serial_number=self.accessory.serial_number,
+                    output_number=self.accessory.output_number,
+                    module=self.module,
+                    accessory=self.accessory,
+                    value=value,
+                    brightness=self.brightness,
+                )
             )
-        )
 
     def get_on(self) -> bool:
+        """Get the on/off state of the dimming light.
+
+        Returns:
+            True if on, False if off.
+        """
         # Emit event and get response
         self.logger.debug("get_on")
 
@@ -153,6 +144,11 @@ class DimmingLight(Accessory):
         return self.is_on
 
     def set_brightness(self, value: int) -> None:
+        """Set the brightness level of the dimming light.
+
+        Args:
+            value: Brightness level (0-100).
+        """
         self.logger.debug(f"set_brightness {value}")
         self.brightness = value
 
@@ -167,6 +163,11 @@ class DimmingLight(Accessory):
         )
 
     def get_brightness(self) -> int:
+        """Get the brightness level of the dimming light.
+
+        Returns:
+            Current brightness level (0-100).
+        """
         self.logger.debug("get_brightness")
 
         # Dispatch event from HAP thread (thread-safe)
