@@ -1,5 +1,9 @@
+"""HomeKit Outlet Accessory.
+
+This module provides an outlet accessory for HomeKit integration.
+"""
+
 import logging
-from typing import Optional
 
 from bubus import EventBus
 from pyhap.accessory import Accessory
@@ -9,17 +13,28 @@ from pyhap.const import CATEGORY_OUTLET
 from xp.models.homekit.homekit_config import HomekitAccessoryConfig
 from xp.models.homekit.homekit_conson_config import ConsonModuleConfig
 from xp.models.protocol.conbus_protocol import (
-    DatapointReceivedEvent,
     OutletGetInUseEvent,
     OutletGetOnEvent,
     OutletSetInUseEvent,
     OutletSetOnEvent,
 )
-from xp.models.telegram.datapoint_type import DataPointType
 
 
 class Outlet(Accessory):
-    """Fake lightbulb, logs what the client sets."""
+    """HomeKit outlet accessory.
+
+    Attributes:
+        category: HomeKit category (CATEGORY_OUTLET).
+        event_bus: Event bus for inter-service communication.
+        logger: Logger instance.
+        identifier: Unique identifier for the accessory.
+        accessory: Accessory configuration.
+        module: Module configuration.
+        is_on: Current on/off state.
+        is_in_use: Current in-use state.
+        char_on: On characteristic.
+        char_outlet_in_use: Outlet in-use characteristic.
+    """
 
     category = CATEGORY_OUTLET
     event_bus: EventBus
@@ -31,9 +46,24 @@ class Outlet(Accessory):
         accessory: HomekitAccessoryConfig,
         event_bus: EventBus,
     ):
+        """Initialize the outlet accessory.
+
+        Args:
+            driver: HAP accessory driver.
+            module: Module configuration.
+            accessory: Accessory configuration.
+            event_bus: Event bus for inter-service communication.
+        """
         super().__init__(driver=driver, display_name=accessory.description)
 
         self.logger = logging.getLogger(__name__)
+
+        identifier = f"{module.serial_number}.{accessory.output_number:02d}"
+        version = accessory.id
+        manufacturer = "Conson"
+        model = ("XP24_outlet",)
+
+        self.identifier = identifier
         self.accessory = accessory
         self.module = module
 
@@ -45,14 +75,9 @@ class Outlet(Accessory):
         )
         self.is_on = False
         self.is_in_use = False
-        self.event_bus.on(DatapointReceivedEvent, self.on_datapoint_received)
 
-        serial = f"{module.serial_number}.{accessory.output_number:02d}"
-        version = accessory.id
-        manufacturer = "Conson"
-        model = ("XP24_outlet",)
         serv_outlet = self.add_preload_service("Outlet")
-        self.set_info_service(version, manufacturer, model, serial)
+        self.set_info_service(version, manufacturer, model, identifier)
         self.char_on = serv_outlet.configure_char(
             "On", setter_callback=self.set_on, getter_callback=self.get_on
         )
@@ -62,27 +87,12 @@ class Outlet(Accessory):
             getter_callback=self.get_outlet_in_use,
         )
 
-    def on_datapoint_received(self, event: DatapointReceivedEvent) -> Optional[bool]:
-
-        if (
-            event.serial_number != self.module.serial_number
-            or event.datapoint_type != DataPointType.MODULE_OUTPUT_STATE
-        ):
-            return None
-
-        is_on = event.data_value[::-1][self.accessory.output_number] == "1"
-        self.is_on = is_on
-        self.is_in_use = is_on
-        self.logger.debug(
-            f"on_datapoint_received "
-            f"serial_number: {event.serial_number}, "
-            f"output_number: {self.accessory.output_number}, "
-            f"data_vale: {event.data_value}"
-            f"is_on: {is_on}"
-        )
-        return is_on
-
     def set_outlet_in_use(self, value: bool) -> None:
+        """Set the in-use state of the outlet.
+
+        Args:
+            value: True if in use, False otherwise.
+        """
         self.logger.debug(f"set_outlet_in_use {value}")
 
         self.is_in_use = value
@@ -98,6 +108,11 @@ class Outlet(Accessory):
         self.logger.debug(f"set_outlet_in_use {value} end")
 
     def get_outlet_in_use(self) -> bool:
+        """Get the in-use state of the outlet.
+
+        Returns:
+            True if in use, False otherwise.
+        """
         # Emit event and get response
         self.logger.debug("get_outlet_in_use")
 
@@ -113,21 +128,32 @@ class Outlet(Accessory):
         return self.is_in_use
 
     def set_on(self, value: bool) -> None:
+        """Set the on/off state of the outlet.
+
+        Args:
+            value: True to turn on, False to turn off.
+        """
         # Emit set event
         self.logger.debug(f"set_on {value}")
-        self.is_on = value
 
-        self.event_bus.dispatch(
-            OutletSetOnEvent(
-                serial_number=self.accessory.serial_number,
-                output_number=self.accessory.output_number,
-                module=self.module,
-                accessory=self.accessory,
-                value=value,
+        if value != self.is_on:
+            self.is_on = value
+            self.event_bus.dispatch(
+                OutletSetOnEvent(
+                    serial_number=self.accessory.serial_number,
+                    output_number=self.accessory.output_number,
+                    module=self.module,
+                    accessory=self.accessory,
+                    value=value,
+                )
             )
-        )
 
     def get_on(self) -> bool:
+        """Get the on/off state of the outlet.
+
+        Returns:
+            True if on, False if off.
+        """
         # Emit event and get response
         self.logger.debug("get_on")
 
