@@ -9,24 +9,45 @@ from twisted.internet.posixbase import PosixReactorBase
 from xp.models import ConbusClientConfig
 from xp.models.homekit.homekit_config import HomekitConfig
 from xp.models.homekit.homekit_conson_config import ConsonModuleListConfig
-from xp.services.conbus.actiontable.actiontable_service import ActionTableService
-from xp.services.conbus.actiontable.msactiontable_service import MsActionTableService
-from xp.services.conbus.conbus_autoreport_service import ConbusAutoreportService
-from xp.services.conbus.conbus_blink_service import ConbusBlinkService
-from xp.services.conbus.conbus_connection_pool import (
-    ConbusConnectionPool,
-    ConbusSocketConnectionManager,
+from xp.services.actiontable.actiontable_serializer import ActionTableSerializer
+from xp.services.actiontable.msactiontable_serializer import MsActionTableSerializer
+from xp.services.actiontable.msactiontable_xp20_serializer import (
+    Xp20MsActionTableSerializer,
 )
+from xp.services.actiontable.msactiontable_xp24_serializer import (
+    Xp24MsActionTableSerializer,
+)
+from xp.services.actiontable.msactiontable_xp33_serializer import (
+    Xp33MsActionTableSerializer,
+)
+from xp.services.conbus.actiontable.actiontable_download_service import (
+    ActionTableService,
+)
+from xp.services.conbus.actiontable.actiontable_list_service import (
+    ActionTableListService,
+)
+from xp.services.conbus.actiontable.actiontable_show_service import (
+    ActionTableShowService,
+)
+from xp.services.conbus.actiontable.actiontable_upload_service import (
+    ActionTableUploadService,
+)
+from xp.services.conbus.actiontable.msactiontable_service import MsActionTableService
+from xp.services.conbus.conbus_blink_all_service import ConbusBlinkAllService
+from xp.services.conbus.conbus_blink_service import ConbusBlinkService
 from xp.services.conbus.conbus_custom_service import ConbusCustomService
-from xp.services.conbus.conbus_datapoint_service import ConbusDatapointService
+from xp.services.conbus.conbus_datapoint_queryall_service import (
+    ConbusDatapointQueryAllService,
+)
+from xp.services.conbus.conbus_datapoint_service import (
+    ConbusDatapointService,
+)
 from xp.services.conbus.conbus_discover_service import ConbusDiscoverService
-from xp.services.conbus.conbus_lightlevel_service import ConbusLightlevelService
-from xp.services.conbus.conbus_linknumber_service import ConbusLinknumberService
 from xp.services.conbus.conbus_output_service import ConbusOutputService
 from xp.services.conbus.conbus_raw_service import ConbusRawService
 from xp.services.conbus.conbus_receive_service import ConbusReceiveService
 from xp.services.conbus.conbus_scan_service import ConbusScanService
-from xp.services.conbus.conbus_service import ConbusService
+from xp.services.conbus.write_config_service import WriteConfigService
 from xp.services.homekit.homekit_cache_service import HomeKitCacheService
 from xp.services.homekit.homekit_conbus_service import HomeKitConbusService
 from xp.services.homekit.homekit_dimminglight_service import HomeKitDimmingLightService
@@ -40,6 +61,7 @@ from xp.services.module_type_service import ModuleTypeService
 from xp.services.protocol.protocol_factory import TelegramFactory
 from xp.services.protocol.telegram_protocol import TelegramProtocol
 from xp.services.reverse_proxy_service import ReverseProxyService
+from xp.services.server.device_service_factory import DeviceServiceFactory
 from xp.services.server.server_service import ServerService
 from xp.services.telegram.telegram_blink_service import TelegramBlinkService
 from xp.services.telegram.telegram_discover_service import TelegramDiscoverService
@@ -55,7 +77,7 @@ class ServiceContainer:
     """
     Service container that manages dependency injection for all XP services.
 
-    Uses the service dependency graph from Service-Dependencies.dot to properly
+    Uses the service dependency graph from Dependencies.dot to properly
     wire up all services with their dependencies.
     """
 
@@ -64,7 +86,6 @@ class ServiceContainer:
         config_path: str = "cli.yml",
         homekit_config_path: str = "homekit.yml",
         conson_config_path: str = "conson.yml",
-        cache_file: str = ".homekit_cache.json",
         server_port: int = 10001,
         reverse_proxy_port: int = 10001,
     ):
@@ -75,7 +96,6 @@ class ServiceContainer:
             config_path: Path to the Conbus CLI configuration file
             homekit_config_path: Path to the HomeKit configuration file
             conson_config_path: Path to the Conson configuration file
-            cache_file: Path to the HomeKit cache file
             server_port: Port for the server service
             reverse_proxy_port: Port for the reverse proxy service
         """
@@ -83,7 +103,6 @@ class ServiceContainer:
         self._config_path = config_path
         self._homekit_config_path = homekit_config_path
         self._conson_config_path = conson_config_path
-        self._cache_file = cache_file
         self._server_port = server_port
         self._reverse_proxy_port = reverse_proxy_port
 
@@ -91,31 +110,13 @@ class ServiceContainer:
 
     def _register_services(self) -> None:
         """Register all services in the container based on dependency graph."""
-
-        # ConbusClientConfig (needed by ConbusConnectionPool)
+        # ConbusClientConfig
         self.container.register(
             ConbusClientConfig,
             factory=lambda: ConbusClientConfig.from_yaml(self._config_path),
             scope=punq.Scope.singleton,
         )
 
-        # Core infrastructure layer - ConbusConnectionPool (singleton)
-        self.container.register(
-            ConbusSocketConnectionManager,
-            factory=lambda: ConbusSocketConnectionManager(
-                cli_config=self.container.resolve(ConbusClientConfig)
-            ),
-            scope=punq.Scope.singleton,
-        )
-
-        self.container.register(
-            ConbusConnectionPool,
-            factory=lambda: ConbusConnectionPool(
-                connection_manager=self.container.resolve(ConbusSocketConnectionManager)
-            ),
-            scope=punq.Scope.singleton,
-        )
-
         # Telegram services layer
         self.container.register(TelegramService, scope=punq.Scope.singleton)
         self.container.register(
@@ -129,22 +130,23 @@ class ServiceContainer:
         self.container.register(TelegramBlinkService, scope=punq.Scope.singleton)
         self.container.register(LinkNumberService, scope=punq.Scope.singleton)
 
-        # ConbusService - depends on ConbusConnectionPool
-        self.container.register(
-            ConbusService,
-            factory=lambda: ConbusService(
-                client_config=self.container.resolve(ConbusClientConfig),
-                connection_pool=self.container.resolve(ConbusConnectionPool),
-            ),
-            scope=punq.Scope.singleton,
-        )
-
         # Conbus services layer
         self.container.register(
             ConbusDatapointService,
             factory=lambda: ConbusDatapointService(
                 telegram_service=self.container.resolve(TelegramService),
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ConbusDatapointQueryAllService,
+            factory=lambda: ConbusDatapointQueryAllService(
+                telegram_service=self.container.resolve(TelegramService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
@@ -152,8 +154,8 @@ class ServiceContainer:
         self.container.register(
             ConbusScanService,
             factory=lambda: ConbusScanService(
-                telegram_service=self.container.resolve(TelegramService),
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
@@ -161,11 +163,8 @@ class ServiceContainer:
         self.container.register(
             ConbusDiscoverService,
             factory=lambda: ConbusDiscoverService(
-                telegram_service=self.container.resolve(TelegramService),
-                telegram_discover_service=self.container.resolve(
-                    TelegramDiscoverService
-                ),
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
@@ -173,9 +172,18 @@ class ServiceContainer:
         self.container.register(
             ConbusBlinkService,
             factory=lambda: ConbusBlinkService(
-                conbus_service=self.container.resolve(ConbusService),
-                discover_service=self.container.resolve(ConbusDiscoverService),
-                telegram_blink_service=self.container.resolve(TelegramBlinkService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
+                telegram_service=self.container.resolve(TelegramService),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ConbusBlinkAllService,
+            factory=lambda: ConbusBlinkAllService(
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
                 telegram_service=self.container.resolve(TelegramService),
             ),
             scope=punq.Scope.singleton,
@@ -184,58 +192,90 @@ class ServiceContainer:
         self.container.register(
             ConbusOutputService,
             factory=lambda: ConbusOutputService(
-                telegram_service=self.container.resolve(TelegramService),
                 telegram_output_service=self.container.resolve(TelegramOutputService),
-                datapoint_service=self.container.resolve(ConbusDatapointService),
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
 
         self.container.register(
-            ConbusLightlevelService,
-            factory=lambda: ConbusLightlevelService(
+            WriteConfigService,
+            factory=lambda: WriteConfigService(
                 telegram_service=self.container.resolve(TelegramService),
-                conbus_service=self.container.resolve(ConbusService),
-                datapoint_service=self.container.resolve(ConbusDatapointService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
 
+        self.container.register(
+            ActionTableSerializer,
+            factory=lambda: ActionTableSerializer,
+            scope=punq.Scope.singleton,
+        )
+
         self.container.register(
             ActionTableService,
             factory=lambda: ActionTableService(
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
+                actiontable_serializer=self.container.resolve(ActionTableSerializer),
                 telegram_service=self.container.resolve(TelegramService),
             ),
             scope=punq.Scope.singleton,
         )
 
+        self.container.register(
+            ActionTableUploadService,
+            factory=lambda: ActionTableUploadService(
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
+                actiontable_serializer=self.container.resolve(ActionTableSerializer),
+                telegram_service=self.container.resolve(TelegramService),
+                conson_config=self.container.resolve(ConsonModuleListConfig),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ActionTableListService,
+            factory=ActionTableListService,
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            ActionTableShowService,
+            factory=ActionTableShowService,
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            Xp20MsActionTableSerializer,
+            factory=lambda: Xp20MsActionTableSerializer,
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            Xp24MsActionTableSerializer,
+            factory=lambda: Xp24MsActionTableSerializer,
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            Xp33MsActionTableSerializer,
+            factory=lambda: Xp33MsActionTableSerializer,
+            scope=punq.Scope.singleton,
+        )
+
         self.container.register(
             MsActionTableService,
             factory=lambda: MsActionTableService(
-                conbus_service=self.container.resolve(ConbusService),
-                telegram_service=self.container.resolve(TelegramService),
-            ),
-            scope=punq.Scope.singleton,
-        )
-
-        self.container.register(
-            ConbusAutoreportService,
-            factory=lambda: ConbusAutoreportService(
-                conbus_service=self.container.resolve(ConbusService),
-                datapoint_service=self.container.resolve(ConbusDatapointService),
-                telegram_service=self.container.resolve(TelegramService),
-            ),
-            scope=punq.Scope.singleton,
-        )
-
-        self.container.register(
-            ConbusLinknumberService,
-            factory=lambda: ConbusLinknumberService(
-                conbus_service=self.container.resolve(ConbusService),
-                datapoint_service=self.container.resolve(ConbusDatapointService),
-                link_number_service=self.container.resolve(LinkNumberService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
+                xp20ms_serializer=self.container.resolve(Xp20MsActionTableSerializer),
+                xp24ms_serializer=self.container.resolve(Xp24MsActionTableSerializer),
+                xp33ms_serializer=self.container.resolve(Xp33MsActionTableSerializer),
                 telegram_service=self.container.resolve(TelegramService),
             ),
             scope=punq.Scope.singleton,
@@ -245,7 +285,8 @@ class ServiceContainer:
             ConbusCustomService,
             factory=lambda: ConbusCustomService(
                 telegram_service=self.container.resolve(TelegramService),
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
@@ -253,7 +294,8 @@ class ServiceContainer:
         self.container.register(
             ConbusRawService,
             factory=lambda: ConbusRawService(
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
@@ -261,7 +303,8 @@ class ServiceContainer:
         self.container.register(
             ConbusReceiveService,
             factory=lambda: ConbusReceiveService(
-                conbus_service=self.container.resolve(ConbusService),
+                cli_config=self.container.resolve(ConbusClientConfig),
+                reactor=self.container.resolve(PosixReactorBase),
             ),
             scope=punq.Scope.singleton,
         )
@@ -282,19 +325,6 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
-        self.container.register(
-            HomeKitCacheService,
-            factory=lambda: HomeKitCacheService(
-                cache_file=self._cache_file,
-                conbus_output_service=self.container.resolve(ConbusOutputService),
-                conbus_lightlevel_service=self.container.resolve(
-                    ConbusLightlevelService
-                ),
-                telegram_service=self.container.resolve(TelegramService),
-            ),
-            scope=punq.Scope.singleton,
-        )
-
         # Create event bus
         self.container.register(
             EventBus,
@@ -331,12 +361,31 @@ class ServiceContainer:
         # Module type services layer
         self.container.register(ModuleTypeService, scope=punq.Scope.singleton)
 
+        # MsActionTable serializers
+        self.container.register(MsActionTableSerializer, scope=punq.Scope.singleton)
+        self.container.register(Xp20MsActionTableSerializer, scope=punq.Scope.singleton)
+        self.container.register(Xp24MsActionTableSerializer, scope=punq.Scope.singleton)
+        self.container.register(Xp33MsActionTableSerializer, scope=punq.Scope.singleton)
+
+        # Device service factory
+        self.container.register(
+            DeviceServiceFactory,
+            factory=lambda: DeviceServiceFactory(
+                xp20ms_serializer=self.container.resolve(Xp20MsActionTableSerializer),
+                xp24ms_serializer=self.container.resolve(Xp24MsActionTableSerializer),
+                xp33ms_serializer=self.container.resolve(Xp33MsActionTableSerializer),
+                ms_serializer=self.container.resolve(MsActionTableSerializer),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
         # Server services layer
         self.container.register(
             ServerService,
             factory=lambda: ServerService(
                 telegram_service=self.container.resolve(TelegramService),
                 discover_service=self.container.resolve(TelegramDiscoverService),
+                device_factory=self.container.resolve(DeviceServiceFactory),
                 config_path="server.yml",
                 port=self._server_port,
             ),
@@ -353,11 +402,12 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
-        # Create protocol
+        # Create protocol with built-in debouncing
         self.container.register(
             TelegramProtocol,
             factory=lambda: TelegramProtocol(
                 event_bus=self.container.resolve(EventBus),
+                debounce_ms=50,
             ),
             scope=punq.Scope.singleton,
         )
@@ -408,6 +458,16 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
+        # Cache service must be registered BEFORE HomeKitConbusService
+        # so it intercepts ReadDatapointEvent first
+        self.container.register(
+            HomeKitCacheService,
+            factory=lambda: HomeKitCacheService(
+                event_bus=self.container.resolve(EventBus),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
         self.container.register(
             HomeKitConbusService,
             factory=lambda: HomeKitConbusService(
@@ -426,12 +486,14 @@ class ServiceContainer:
         self.container.register(
             HomeKitService,
             factory=lambda: HomeKitService(
+                cli_config=self.container.resolve(ConbusClientConfig),
                 event_bus=self.container.resolve(EventBus),
                 telegram_factory=self.container.resolve(TelegramFactory),
                 reactor=self.container.resolve(PosixReactorBase),
                 lightbulb_service=self.container.resolve(HomeKitLightbulbService),
                 outlet_service=self.container.resolve(HomeKitOutletService),
                 dimminglight_service=self.container.resolve(HomeKitDimmingLightService),
+                cache_service=self.container.resolve(HomeKitCacheService),
                 conbus_service=self.container.resolve(HomeKitConbusService),
                 module_factory=self.container.resolve(HomekitHapService),
                 telegram_service=self.container.resolve(TelegramService),
