@@ -2,6 +2,7 @@
 
 from unittest.mock import Mock
 
+from xp.models import ModuleTypeCode
 from xp.models.telegram.datapoint_type import DataPointType
 from xp.models.telegram.system_function import SystemFunction
 from xp.services.server.base_server_service import BaseServerService
@@ -11,9 +12,14 @@ class ConcreteServerService(BaseServerService):
     """Concrete implementation for testing."""
 
     def __init__(self, serial_number: str):
+        """Initialize the concrete server service for testing.
+
+        Args:
+            serial_number: Serial number of the device.
+        """
         super().__init__(serial_number)
         self.device_type = "TEST"
-        self.module_type_code = 0x33
+        self.module_type_code = ModuleTypeCode.XP20
         self.hardware_version = "1.0"
         self.software_version = "2.0"
 
@@ -27,7 +33,7 @@ class TestBaseServerServiceInit:
 
         assert service.serial_number == "12345"
         assert service.device_type == "TEST"
-        assert service.module_type_code == 0x33
+        assert service.module_type_code == ModuleTypeCode.XP20
         assert service.device_status == "OK"
         assert service.link_number == 1
         assert service.temperature == "+23,5§C"
@@ -67,7 +73,7 @@ class TestBaseServerServiceDatapointResponse:
 
         assert response is not None
         assert "R12345F02" in response
-        assert "33" in response
+        assert "33" in response  # ModuleTypeCode.XP20.value == 33
 
     def test_generate_datapoint_type_response_sw_version(self):
         """Test generating software version datapoint response."""
@@ -92,7 +98,7 @@ class TestBaseServerServiceDatapointResponse:
     def test_generate_datapoint_type_response_error_code(self):
         """Test generating error code datapoint response."""
         response = ConcreteServerService("12345").generate_datapoint_type_response(
-            DataPointType.MODULE_TYPE
+            DataPointType.MODULE_STATE
         )
 
         assert response is not None
