@@ -1,4 +1,4 @@
-"""Tests for BlinkService"""
+"""Tests for BlinkService."""
 
 from unittest.mock import Mock
 
@@ -11,15 +11,15 @@ from xp.services.telegram.telegram_blink_service import BlinkError, TelegramBlin
 
 
 class TestBlinkService:
-    """Test cases for BlinkService"""
+    """Test cases for BlinkService."""
 
     def test_init(self):
-        """Test initialization"""
+        """Test initialization."""
         service = TelegramBlinkService()
         assert isinstance(service, TelegramBlinkService)
 
     def test_generate_blink_telegram_valid(self):
-        """Test generating valid blink telegram"""
+        """Test generating valid blink telegram."""
         service = TelegramBlinkService()
 
         # Test case from specification: <S0012345008F05D00FN>
@@ -37,7 +37,7 @@ class TestBlinkService:
         assert len(result) == 21  # <S{10}F05D00{2}> = 21 chars
 
     def test_generate_blink_telegram_invalid_serial(self):
-        """Test generating blink telegram with invalid serial number"""
+        """Test generating blink telegram with invalid serial number."""
         service = TelegramBlinkService()
 
         # Test empty serial
@@ -57,7 +57,7 @@ class TestBlinkService:
             service.generate_blink_telegram("123456789A", "on")
 
     def test_generate_unblink_telegram_valid(self):
-        """Test generating valid unblink telegram"""
+        """Test generating valid unblink telegram."""
         service = TelegramBlinkService()
 
         # Test case from specification: <S0012345011F06D00FK>
@@ -75,7 +75,7 @@ class TestBlinkService:
         assert len(result) == 21  # <S{10}F06D00{2}> = 21 chars
 
     def test_generate_unblink_telegram_invalid_serial(self):
-        """Test generating unblink telegram with invalid serial number"""
+        """Test generating unblink telegram with invalid serial number."""
         service = TelegramBlinkService()
 
         # Test empty serial
@@ -95,7 +95,7 @@ class TestBlinkService:
             service.generate_blink_telegram("123456789A", "off")
 
     def test_create_blink_telegram_object(self):
-        """Test creating SystemTelegram object for blink operation"""
+        """Test creating SystemTelegram object for blink operation."""
         telegram = TelegramBlinkService().create_blink_telegram_object("0012345008")
 
         assert isinstance(telegram, SystemTelegram)
@@ -106,7 +106,7 @@ class TestBlinkService:
         assert telegram.checksum == "FN"
 
     def test_create_unblink_telegram_object(self):
-        """Test creating SystemTelegram object for unblink operation"""
+        """Test creating SystemTelegram object for unblink operation."""
         telegram = TelegramBlinkService().create_unblink_telegram_object("0012345011")
 
         assert isinstance(telegram, SystemTelegram)
@@ -117,7 +117,7 @@ class TestBlinkService:
         assert telegram.checksum == "FG"
 
     def test_is_ack_response(self):
-        """Test identifying ACK responses"""
+        """Test identifying ACK responses."""
         service = TelegramBlinkService()
 
         # Create mock ACK response (F18D from spec)
@@ -139,7 +139,7 @@ class TestBlinkService:
         assert service.is_ack_response(other_reply) is False
 
     def test_is_nak_response(self):
-        """Test identifying NAK responses"""
+        """Test identifying NAK responses."""
         service = TelegramBlinkService()
 
         # Create mock NAK response (F19D from spec)
@@ -161,7 +161,7 @@ class TestBlinkService:
         assert service.is_nak_response(other_reply) is False
 
     def test_blink_unblink_telegram_format(self):
-        """Test that generated telegrams follow correct format"""
+        """Test that generated telegrams follow correct format."""
         service = TelegramBlinkService()
 
         # Test blink telegram structure
@@ -177,7 +177,7 @@ class TestBlinkService:
         assert unblink_telegram.endswith(">")
 
     def test_different_serial_numbers(self):
-        """Test blink/unblink with various serial numbers"""
+        """Test blink/unblink with various serial numbers."""
         service = TelegramBlinkService()
 
         test_serials = [
