@@ -5,8 +5,9 @@ following the architecture pattern for service testing.
 """
 
 import pytest
-from xp.services.telegram_checksum_service import TelegramChecksumService
+
 from xp.models.response import Response
+from xp.services.telegram.telegram_checksum_service import TelegramChecksumService
 
 
 class TestChecksumService:
