@@ -3,7 +3,7 @@
 import pytest
 
 from xp.models.actiontable.msactiontable_xp20 import InputChannel, Xp20MsActionTable
-from xp.services.conbus.actiontable.msactiontable_xp20_serializer import (
+from xp.services.actiontable.msactiontable_xp20_serializer import (
     GROUP_ON_OFF_INDEX,
     INVERT_INDEX,
     SA_FUNCTION_INDEX,
@@ -15,11 +15,11 @@ from xp.utils.serialization import de_nibbles
 
 
 class TestXp20MsActionTableSerializer:
-    """Test cases for Xp20MsActionTableSerializer"""
+    """Test cases for Xp20MsActionTableSerializer."""
 
     @pytest.fixture
     def sample_action_table(self):
-        """Create sample action table for testing"""
+        """Create sample action table for testing."""
         return Xp20MsActionTable(
             input1=InputChannel(
                 invert=True,
@@ -54,19 +54,19 @@ class TestXp20MsActionTableSerializer:
 
     @pytest.fixture
     def sample_telegram_data(self):
-        """Sample telegram data based on specification example (64 chars)"""
-        return "AAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+        """Sample telegram data based on specification example (68 chars)."""
+        return "AAAAAAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
 
     def test_to_data_serialization(self, sample_action_table):
-        """Test serialization to telegram format"""
+        """Test serialization to telegram format."""
         result = Xp20MsActionTableSerializer.to_data(sample_action_table)
 
         # Should return 64-character hex string
-        assert len(result) == 64
+        assert len(result) == 68
         assert all(c in "ABCDEFGHIJKLMNOP" for c in result)
 
     def test_from_data_deserialization(self, sample_telegram_data):
-        """Test deserialization from telegram data"""
+        """Test deserialization from telegram data."""
         action_table = Xp20MsActionTableSerializer.from_data(sample_telegram_data)
 
         # Verify it's a valid Xp20MsActionTable
@@ -83,7 +83,7 @@ class TestXp20MsActionTableSerializer:
         assert action_table.input8 is not None
 
     def test_round_trip_serialization(self, sample_action_table):
-        """Test that serialization followed by deserialization preserves data"""
+        """Test that serialization followed by deserialization preserves data."""
         # Serialize to data
         serialized = Xp20MsActionTableSerializer.to_data(sample_action_table)
 
@@ -116,12 +116,12 @@ class TestXp20MsActionTableSerializer:
         assert deserialized.input2.ta_function == sample_action_table.input2.ta_function
 
     def test_invalid_data_length(self):
-        """Test that invalid data length raises ValueError"""
-        with pytest.raises(ValueError, match="must be 64 characters long"):
+        """Test that invalid data length raises ValueError."""
+        with pytest.raises(ValueError, match="must be 68 characters long"):
             Xp20MsActionTableSerializer.from_data("INVALID")
 
     def test_byte_to_bits_conversion(self):
-        """Test byte to bits conversion helper"""
+        """Test byte to bits conversion helper."""
         from xp.utils.serialization import byte_to_bits
 
         # Test known values
@@ -141,7 +141,7 @@ class TestXp20MsActionTableSerializer:
         ]
 
     def test_default_input_channel(self):
-        """Test that default input channel has correct values"""
+        """Test that default input channel has correct values."""
         channel = InputChannel()
         assert channel.invert is False
         assert channel.short_long is False
@@ -152,7 +152,7 @@ class TestXp20MsActionTableSerializer:
         assert channel.ta_function is False
 
     def test_and_functions_encoding(self):
-        """Test AND functions encoding/decoding"""
+        """Test AND functions encoding/decoding."""
         action_table = Xp20MsActionTable()
         action_table.input1.and_functions = [
             True,
@@ -180,7 +180,7 @@ class TestXp20MsActionTableSerializer:
         ]
 
     def test_all_flags_true(self):
-        """Test encoding/decoding with all flags set to True"""
+        """Test encoding/decoding with all flags set to True."""
         action_table = Xp20MsActionTable()
         for i in range(1, 9):
             channel = getattr(action_table, f"input{i}")
@@ -204,21 +204,8 @@ class TestXp20MsActionTableSerializer:
             assert channel.sa_function is True
             assert channel.ta_function is True
 
-    def test_from_telegrams_compatibility(self):
-        """Test legacy from_telegrams method"""
-        # Create a mock full telegram string
-        mock_telegram = (
-            "0123456789ABCDEF"  # 16 chars header
-            "AAAA"  # 4 chars count
-            "AAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"  # 64 chars data
-            "PADDING"  # Additional chars
-        )
-
-        result = Xp20MsActionTableSerializer.from_telegrams(mock_telegram)
-        assert isinstance(result, Xp20MsActionTable)
-
     def test_encoding_bit_positions(self):
-        """Test that bit positions are correctly encoded"""
+        """Test that bit positions are correctly encoded."""
         action_table = Xp20MsActionTable()
 
         # Set specific bits for input1 (position 0)
@@ -231,7 +218,8 @@ class TestXp20MsActionTableSerializer:
         action_table.input8.ta_function = True
 
         serialized = Xp20MsActionTableSerializer.to_data(action_table)
-        raw_bytes = de_nibbles(serialized)
+        # Skip the 4-character "AAAA" prefix when de-nibbling
+        raw_bytes = de_nibbles(serialized[4:])
 
         # Check bit positions
         assert raw_bytes[SHORT_LONG_INDEX] & 1 != 0  # input1 bit 0
@@ -241,9 +229,9 @@ class TestXp20MsActionTableSerializer:
         assert raw_bytes[TA_FUNCTION_INDEX] & 128 != 0  # input8 bit 7
 
     def test_specification_example(self):
-        """Test with the example telegram from specification"""
+        """Test with the example telegram from specification."""
         example_data = (
-            "AAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+            "AAAAAAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
         )
 
         # This should decode without errors
@@ -265,3 +253,78 @@ class TestXp20MsActionTableSerializer:
             assert original_channel.and_functions == decoded_channel.and_functions
             assert original_channel.sa_function == decoded_channel.sa_function
             assert original_channel.ta_function == decoded_channel.ta_function
+
+    def test_from_telegrams_from_data(self):
+        """Test round-trip serialization with default/empty action table data."""
+        # 64 characters - all A's represent a completely empty/default action table
+        valid_msactiontable = (
+            "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+        )
+
+        # Deserialize from data
+        msactiontable = Xp20MsActionTableSerializer.from_data(valid_msactiontable)
+
+        # Verify it's a valid Xp20MsActionTable with default values
+        assert isinstance(msactiontable, Xp20MsActionTable)
+        for i in range(1, 9):
+            channel = getattr(msactiontable, f"input{i}")
+            assert channel.invert is False
+            assert channel.short_long is False
+            assert channel.group_on_off is False
+            assert channel.and_functions == [False] * 8
+            assert channel.sa_function is False
+            assert channel.ta_function is False
+
+        # Re-serialize back to data
+        msactiontable_data = Xp20MsActionTableSerializer.to_data(msactiontable)
+
+        # Verify round-trip preserves the original data
+        assert valid_msactiontable == msactiontable_data
+
+    def test_real_xp20_telegram(self):
+        """Test deserialization of a real XP20 msactiontable telegram."""
+        # Real telegram from XP20 device
+        telegram = "<R0020041824F17DAAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFP>"
+
+        # Extract data portion (skip header at 0-15, skip count at 16-19, take 64 chars at 20-83)
+        data = telegram[16:84]
+        assert len(data) == 68
+
+        # Deserialize the action table
+        action_table = Xp20MsActionTableSerializer.from_data(data)
+
+        # Verify it's a valid Xp20MsActionTable
+        assert isinstance(action_table, Xp20MsActionTable)
+
+        # Verify all 8 input channels are present
+        for i in range(1, 9):
+            channel = getattr(action_table, f"input{i}")
+            assert channel is not None
+            assert isinstance(channel, InputChannel)
+
+        # Test round-trip: serialize and deserialize should preserve data
+        serialized = Xp20MsActionTableSerializer.to_data(action_table)
+        deserialized = Xp20MsActionTableSerializer.from_data(serialized)
+
+        # Verify round-trip preserves all values
+        for i in range(1, 9):
+            original = getattr(action_table, f"input{i}")
+            result = getattr(deserialized, f"input{i}")
+
+            assert original.invert == result.invert
+            assert original.short_long == result.short_long
+            assert original.group_on_off == result.group_on_off
+            assert original.and_functions == result.and_functions
+            assert original.sa_function == result.sa_function
+            assert original.ta_function == result.ta_function
+
+    def test_serialize_back_and_forth(self):
+        """Test that default values work correctly."""
+        telegram = "<R0020037487F17DAAAAAAAAAAABACAEAIBACAEAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFL>"
+
+        # Test serialization with defaults
+        serialized_table = telegram[16:84]
+        deserialized = Xp20MsActionTableSerializer.from_data(serialized_table)
+        serialized = Xp20MsActionTableSerializer.to_data(deserialized)
+
+        assert serialized_table == serialized
