@@ -5,21 +5,21 @@ import pytest
 from xp.models.actiontable.msactiontable_xp24 import InputAction, Xp24MsActionTable
 from xp.models.telegram.input_action_type import InputActionType
 from xp.models.telegram.timeparam_type import TimeParam
-from xp.services.conbus.actiontable.msactiontable_xp24_serializer import (
+from xp.services.actiontable.msactiontable_xp24_serializer import (
     Xp24MsActionTableSerializer,
 )
 from xp.utils.serialization import de_nibbles
 
 
 class TestXp24MsActionTableSerializer:
-    """Test cases for Xp24MsActionTableSerializer"""
+    """Test cases for Xp24MsActionTableSerializer."""
 
     @pytest.fixture
     def sample_action_table(self):
-        """Create sample action table for testing"""
+        """Create sample action table for testing."""
         return Xp24MsActionTable(
             input1_action=InputAction(InputActionType.TOGGLE, TimeParam.NONE),
-            input2_action=InputAction(InputActionType.TURNON, TimeParam.T5SEC),
+            input2_action=InputAction(InputActionType.ON, TimeParam.T5SEC),
             input3_action=InputAction(InputActionType.LEVELSET, TimeParam.T5SEC),
             input4_action=InputAction(InputActionType.SCENESET, TimeParam.T5SEC),
             mutex12=True,
@@ -31,7 +31,7 @@ class TestXp24MsActionTableSerializer:
 
     @pytest.fixture
     def sample_telegrams(self):
-        """Create sample telegrams for testing"""
+        """Create sample telegrams for testing."""
         return [
             "<R0020044989F17DAAAAADAAADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFA>",
             "<R0020044966F17DAAAAADAAADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFB>",
@@ -40,23 +40,8 @@ class TestXp24MsActionTableSerializer:
             "<R0020044964F17DAAAAABAGADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFD>",
         ]
 
-    def test_from_telegrams_basic(self, sample_telegrams: list[str]) -> None:
-        """Test basic telegram parsing"""
-
-        assert sample_telegrams
-        action_table = Xp24MsActionTableSerializer.from_telegrams(sample_telegrams[0])
-
-        # Verify it's a valid Xp24ActionTable
-        assert isinstance(action_table, Xp24MsActionTable)
-
-        # Check that we have 4 input actions
-        assert action_table.input1_action is not None
-        assert action_table.input2_action is not None
-        assert action_table.input3_action is not None
-        assert action_table.input4_action is not None
-
     def test_from_telegrams_invalid_hex_data(self):
-        """Test that invalid hex data raises ValueError with non-hexadecimal characters"""
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
         # This telegram contains non-hex characters that cause from_hex() to fail
         # Based on the debug log: '<R0020044989F17DAAAAADAAADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFA>'
         valid_telegram = (
@@ -79,8 +64,20 @@ class TestXp24MsActionTableSerializer:
         assert not msactiontable.mutex12
         assert not msactiontable.mutex34
 
+    def test_from_telegrams_from_data(self):
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
+        # This telegram contains non-hex characters that cause from_hex() to fail
+        # Based on the debug log: '<R0020044989F17DAAAAADAAADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFA>'
+        valid_msactiontable = (
+            "AAAAADAAADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
+        )
+
+        msactiontable = Xp24MsActionTableSerializer.from_data(valid_msactiontable)
+        msactiontable_data = Xp24MsActionTableSerializer.to_data(msactiontable)
+        assert valid_msactiontable == msactiontable_data
+
     def test_from_telegrams_invalid_hex_data2(self):
-        """Test that invalid hex data raises ValueError with non-hexadecimal characters"""
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
         # This telegram contains non-hex characters that cause from_hex() to fail
         # Based on the debug log: '<R0020044964F17DAAAAABAGADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFD>'
         valid_telegram = (
@@ -88,7 +85,7 @@ class TestXp24MsActionTableSerializer:
         )
 
         msactiontable = Xp24MsActionTableSerializer.from_data(valid_telegram)
-        assert msactiontable.input1_action.type == InputActionType.TURNON
+        assert msactiontable.input1_action.type == InputActionType.ON
         assert msactiontable.input2_action.type == InputActionType.TOGGLE
         assert msactiontable.input3_action.type == InputActionType.TOGGLE
         assert msactiontable.input4_action.type == InputActionType.TOGGLE
@@ -104,28 +101,28 @@ class TestXp24MsActionTableSerializer:
         assert not msactiontable.mutex34
 
     def test_from_telegrams_de_nibble_0(self):
-        """Test that invalid hex data raises ValueError with non-hexadecimal characters"""
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
         nibble = "AA"
 
         result = de_nibbles(nibble)
         assert bytearray([0]) == result
 
     def test_from_telegrams_de_nibble_1(self):
-        """Test that invalid hex data raises ValueError with non-hexadecimal characters"""
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
         nibble = "AB"
 
         result = de_nibbles(nibble)
         assert bytearray([1]) == result
 
     def test_from_telegrams_de_nibble_01(self):
-        """Test that invalid hex data raises ValueError with non-hexadecimal characters"""
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
         nibble = "AAAB"
 
         result = de_nibbles(nibble)
         assert bytearray([0, 1]) == result
 
     def test_from_telegrams_de_nibble_big(self):
-        """Test that invalid hex data raises ValueError with non-hexadecimal characters"""
+        """Test that invalid hex data raises ValueError with non-hexadecimal characters."""
         nibble = "AAAAADAAADAAADAAADAAAAAAAMAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
 
         result = de_nibbles(nibble)
